@@ -1,7 +1,7 @@
 from django.contrib import admin
 from django.conf import settings
 
-if hasattr(settings, 'SHOW_APP_EXAMPLE_UI'):
+if hasattr(settings, 'DJANGO_UI_SHOW_MODEL_EXAMPLE_DYNAMIC'):
     from django_ui.forms import ModelExampleForm
     from django_ui.models import ModelExample
 
@@ -17,10 +17,12 @@ if hasattr(settings, 'SHOW_APP_EXAMPLE_UI'):
 
 if hasattr(settings, 'USE_APP_THEME_UI_ADMIN'):
     from django_ui.models import ThemeUI
+    from django_ui.forms import ThemeUIForm
 
 
     class SettingsUIAdmin(admin.ModelAdmin):
         model = ThemeUI
+        form = ThemeUIForm
         list_display = ('name_theme', 'applied', 'site_name', 'title_window',)
 
         def save_model(self, request, obj, form, change):
